exceptiontools.ContainmentError
===============================

.. inheritance-diagram:: abjad.tools.exceptiontools.ContainmentError.ContainmentError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.ContainmentError.ContainmentError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.ContainmentError.ContainmentError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ContainmentError.ContainmentError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ContainmentError.ContainmentError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ContainmentError.ContainmentError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ContainmentError.ContainmentError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ContainmentError.ContainmentError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ContainmentError.ContainmentError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ContainmentError.ContainmentError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
